# torch-norms
t-norms in PyTorch

[![pminervini](https://circleci.com/gh/pminervini/torch-norms.svg?style=svg&circle-token=7fcedbc3dd5c566046078a2d2c44c7f7e10c8316)](https://circleci.com/gh/pminervini/torch-norms)